<h1 align="center">dbini-torch</p>

<p align="center">
    <a href="https://badge.fury.io/py/dbini-torch"><img src="https://badge.fury.io/py/dbini-torch.svg" alt="PyPI version" height="18"></a>
    <a href="https://github.com/sampepose/dbini-torch/actions/workflows/pytest.yml"><img src="https://github.com/sampepose/dbini-torch/actions/workflows/pytest.yml/badge.svg" alt="PyTest" height="18"></a>
    <a href="https://opensource.org/licenses/MIT"><img src="https://img.shields.io/badge/License-MIT-yellow.svg" alt="License: MIT" height="18"></a>
</p>

Pytorch version of bilateral normal integration.

Especially optimized for fast CUDA execution.

## Acknowledgements

This project is inspired by the original author's work in [numpy](https://github.com/xucao-42/bilateral_normal_integration)

Project boilerplate borrowed from the great @jonmorton and [haven](https://github.com/jonmorton/haven).